@@ -1,7 +1,6 @@
 from django.core.management import call_command
 from django.test import TestCase
 from elasticutils import get_es
-from pyelasticsearch.exceptions import ElasticHttpNotFoundError
 
 from elastimorphic.conf import settings
 from elastimorphic.models import polymorphic_indexable_registry
@@ -20,7 +19,4 @@ class BaseIndexableTestCase(TestCase):
 
     def delete_indexes_with_suffix(self, suffix):
         for base_class in polymorphic_indexable_registry.families.keys():
-            try:
-                self.es.delete_index(base_class.get_index_name() + "_" + suffix)
-            except ElasticHttpNotFoundError:
-                pass
+            self.es.indices.delete(index=base_class.get_index_name() + "_" + suffix, ignore=404)
